<?php
/*
Plugin Name: WP socialshareprivacy
Plugin URI: http://wordpress.org/extend/plugins/wp-socialshareprivacy/
Version: 0.4
Description: Adds 2-click-privacy social buttons (Facebook, Twitter, G+). See <a href="http://www.heise.de/ct/artikel/2-Klicks-fuer-mehr-Datenschutz-1333879.html">article on heise online</a>.
Author: Philipp Bochskandl
Text Domain: wp-socialshareprivacy

    Copyright 2011  Philipp Bochskandl

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
    
*/


function addContent($content = '') {
	if ( !is_singular() ) {
		return $content;
	}
	
	$base_url = plugins_url('/wp-socialshareprivacy/');
	$options = array(
		info_link      => 'http://www.heise.de/ct/artikel/2-Klicks-fuer-mehr-Datenschutz-1333879.html',
		txt_help       => 'Wenn Sie diese Felder durch einen Klick aktivieren, werden Informationen an Facebook, Twitter oder Google in die USA &uuml;bertragen und unter Umst&auml;nden auch dort gespeichert. N&auml;heres erfahren Sie durch einen Klick auf das <em>i</em>.',
		settings_perma => 'Dauerhaft aktivieren und Daten&uuml;ber&shy;tragung zustimmen:',
		cookie_path    => '/',
		cookie_expire  => 365,
		css_path       => $base_url . 'socialshareprivacy.css',
		services       => array(
			facebook => array(
				status          => 'on',
				app_id          => 'FIXME',
				dummy_img       => $base_url . 'images/dummy_facebook.png',
				txt_info        => '2 Klicks f&uuml;r mehr Datenschutz: Erst wenn Sie hier klicken, wird der Button aktiv und Sie k&ouml;nnen Ihre Empfehlung an Facebook senden. Schon beim Aktivieren werden Daten an Dritte &uuml;bertragen &ndash; siehe <em>i</em>.',
				txt_fb_off      => 'nicht mit Facebook verbunden',
				txt_fb_on       => 'mit Facebook verbunden',
				display_name    => 'Facebook',
				referrer_track  => '',
				language        => 'de_DE'
			),
			twitter  => array(
				status          => 'on',
				dummy_img       => $base_url . 'images/dummy_twitter.png',
				txt_info        => '2 Klicks f&uuml;r mehr Datenschutz: Erst wenn Sie hier klicken, wird der Button aktiv und Sie k&ouml;nnen Ihre Empfehlung an Twitter senden. Schon beim Aktivieren werden Daten an Dritte &uuml;bertragen &ndash; siehe <em>i</em>.',
				txt_twitter_off => 'nicht mit Twitter verbunden',
				txt_twitter_on  => 'mit Twitter verbunden',
				display_name    => 'Twitter',
				referrer_track  => '',
				tweet_text      => 'getTweetText'
			),
			gplus    => array(
				status          => 'on',
				dummy_img       => $base_url . 'images/dummy_gplus.png',
				txt_info        => '2 Klicks f&uuml;r mehr Datenschutz: Erst wenn Sie hier klicken, wird der Button aktiv und Sie k&ouml;nnen Ihre Empfehlung an Google+ senden. Schon beim Aktivieren werden Daten an Dritte &uuml;bertragen &ndash; siehe <em>i</em>.',
				txt_twitter_off => 'nicht mit Google+ verbunden',
				txt_twitter_on  => 'mit Google+ verbunden',
				display_name    => 'Google+',
				referrer_track  => '',
				language        => 'de'
			)
		)
	);
	if ( get_option('wpssp_options' ) ) {
		foreach (get_option('wpssp_options') as $key => $value) {
			if ( isset($value) && strlen($value) ) {
				if ( preg_match('/^services_(facebook|twitter|gplus)_(.*)$/', $key, $matches ) ) {
					$options[services][$matches[1]][$matches[2]] = $value;
				}
				else {
					$options[$key] = $value;
				}
			} 
		}
	}
	$content .= '<div id="socialshareprivacy"></div>';
	$content .= "
		<script>
		(function(\$){
			var options = " . json_encode($options) . ";
			options.cookie_domain = document.location.host;
			$(document).ready(function(){
				\$('#socialshareprivacy').socialSharePrivacy(options);
			});
		})(jQuery);
		</script>
	";
	return $content;
}

function enqueue_styles() {
	wp_enqueue_style('wp-socialshareprivacy', '/wp-content/plugins/wp-socialshareprivacy/socialshareprivacy.css');
}
 
function enqueue_scripts() {
	wp_enqueue_script('jquery');
	wp_enqueue_script('wp-socialshareprivacy', '/wp-content/plugins/wp-socialshareprivacy/jquery.socialshareprivacy.min.js');
}

function create_admin_menu() {
	add_options_page(
		'WP socialshareprivacy Settings',
		'WP socialshareprivacy',
		'administrator',
		'wp-socialshareprivacy',
		'wpssp_settings_page',
		plugins_url('/wp-socialshareprivacy/screenshot-4.jpg')
	);
	add_action( 'admin_init', 'register_settings' );
}

function register_settings() {
	register_setting( 'wpssp-settings-group', 'wpssp_options' );
	
	//  $id, $title, $callback, $page 
	add_settings_section('wpssp_g', 'Allgemeines', 'admin_general_description', 'wpssp');
	add_settings_section('wpssp_fb', 'Facebook', 'admin_facebook_description', 'wpssp');
	add_settings_section('wpssp_tw', 'Twitter', 'admin_twitter_description', 'wpssp');
	add_settings_section('wpssp_gp', 'Google+', 'admin_gplus_description', 'wpssp');
	
	// $id, $title, $callback, $page, $section, $args
	$fields = array(
		info_link                        => array( 'Info-Link', 'wpssp_g', 'Link zu detaillierter Datenschutz-Info' ),
		txt_help                         => array( 'Hilfetext', 'wpssp_g', 'MouseOver-Text des <em>i</em>-Icons' ),
		settings_perma                   => array( 'Info-Text', 'wpssp_g', 'Überschrift des Einstellungsmenüs' ),
		cookie_domain                    => array( 'Cookie-Domain', 'wpssp_g', 'Domain, für die das Cookie gültig ist' ),
		cookie_path                      => array( 'Cookie-Path', 'wpssp_g', 'Pfad der Gültigkeit des Cookies' ),
		cookie_expire                    => array( 'Cookie-Expire-Time', 'wpssp_g', 'Dauer, die das Cookie gültig ist, in Tagen' ),
		
		services_facebook_status         => array( 'Status', 'wpssp_fb', '<code>on</code>, wenn aktiviert, andernfalls <code>off</code>'),
		services_facebook_app_id         => array( '<b>App-ID</b>', 'wpssp_fb', 'Facebook App-ID; Sie ist nötig um den Empfehlen-Button von Facebook nutzen zu können.' ),
		services_facebook_display_name   => array( 'Anzeigename', 'wpssp_fb', 'Schreibweise des Service in den Optionen' ),
		services_facebook_txt_info       => array( 'Info-Text', 'wpssp_fb', 'MouseOver-Text des Empfehlen-Buttons' ),
		services_facebook_txt_fb_on      => array( 'Statusmeldung <code>on</code>', 'wpssp_fb', 'Text-Entsprechung der Schalter-Grafik im eingeschalteten Zustand, in der Regel nicht sichtbar für den User'),
		services_facebook_txt_fb_off     => array( 'Statusmeldung <code>off</code>', 'wpssp_fb', 'Text-Entsprechung der Schalter-Grafik im ausgeschalteten Zustand, in der Regel nicht sichtbar für den User'),
		services_facebook_referrer_track => array( 'Referrer Track', 'wpssp_fb', 'Wird ans Ende der URL gehängt, kann zum Tracken des Referrers genutzt werden' ),
		services_facebook_language       => array( 'Sprache', 'wpssp_fb', 'Spracheinstellung, etwa "de_DE"'),
		
		services_twitter_status          => array( 'Status', 'wpssp_tw', '<code>on</code>, wenn aktiviert, andernfalls <code>off</code>' ),
		services_twitter_tweet_text      => array( 'Tweet-Text', 'wpssp_tw', 'Der übergebene Texte <code>de_DE</code>er auf 120 Zeichen gekürzt und beim letzten Leerzeichen mit &hellip; ersetzt.'),
		services_twitter_display_name    => array( 'Anzeigename', 'wpssp_tw', 'Schreibweise des Service in den Optionen' ),
		services_twitter_info            => array( 'Info-Text', 'wpssp_tw', 'MouseOver-Text des Empfehlen-Buttons' ),
		services_twitter_txt_fb_on       => array( 'Statusmeldung <code>on</code>', 'wpssp_tw', 'Text-Entsprechung der Schalter-Grafik im eingeschalteten Zustand, in der Regel nicht sichtbar für den User'),
		services_twitter_txt_fb_off      => array( 'Statusmeldung <code>off</code>', 'wpssp_tw', 'Text-Entsprechung der Schalter-Grafik im ausgeschalteten Zustand, in der Regel nicht sichtbar für den User'),
		services_twitter_referrer_track  => array( 'Referrer Track', 'wpssp_tw', 'Wird ans Ende der URL gehängt, kann zum Tracken des Referrers genutzt werden' ),
		
		services_gplus_status            => array( 'Status', 'wpssp_gp', '<code>on</code>, wenn aktiviert, andernfalls <code>off</code>'),
		services_gplus_display_name      => array( 'Anzeigename', 'wpssp_gp', 'Schreibweise des Service in den Optionen' ),
		services_gplus_txt_info          => array( 'Info-Text', 'wpssp_gp', 'MouseOver-Text des Empfehlen-Buttons' ),
		services_gplus_txt_fb_on         => array( 'Statusmeldung <code>on</code>', 'wpssp_gp', 'Text-Entsprechung der Schalter-Grafik im eingeschalteten Zustand, in der Regel nicht sichtbar für den User'),
		services_gplus_txt_fb_off        => array( 'Statusmeldung <code>off</code>', 'wpssp_gp', 'Text-Entsprechung der Schalter-Grafik im ausgeschalteten Zustand, in der Regel nicht sichtbar für den User'),
		services_gplus_referrer_track    => array( 'Referrer Track', 'wpssp_gp', 'Wird ans Ende der URL gehängt, kann zum Tracken des Referrers genutzt werden' ),
		services_gplus_language          => array( 'Sprache', 'wpssp_gp', 'Spracheinstellung, etwa "de"')
	);
	foreach ( $fields as $name => $context ) {
		add_settings_field(
			"wpssp_$name",
			$context[0],
			function() use ($name, $context) { echo _input_for($name, $context[2]); },
			'wpssp',
			$context[1]
		);
	}
}

function _input_for($option, $description) {
	$options = get_option('wpssp_options');
	return sprintf(
		'<input name="wpssp_options[%s]" type="text" value="%s" /> <span class="description">%s</span>',
		$option,
		$options[$option],
		$description
	);
}

function admin_general_description() {
	?><p><b>Wenn Optionen leergelassen werden, wird der Standardwert aus dem Heise-Plugin verwendet.</b></p><?php
}

function admin_facebook_description() {
	?>
	<h4 id="fb_app-id">Hinweis zur Facebook App-ID</h4>
	<p>
	Für den &bdquo;Empfehlen&ldquo;-Button von Facebook benötigt man eine Facebook App-ID. Diese kann man sich mit seinem verifizierten Facebook-Konto auf den Developer-Seiten erzeugen.
	</p>
	<ol id="fb_app_id_step_by_step">
	<li>Einloggen bei Facebook</li>
	<li>Konto verifizieren mittels Handy-Nummer (oder Kreditkartendaten)<br />
	<a href="https://www.facebook.com/settings?tab=mobile">https://www.facebook.com/settings?tab=mobile</a>
	Option Handy-Nr.:<br />
	Handy-Nr. eintragen und anschließend per SMS empfangenen Bestätigungscode in das Feld auf der rechten Seite eintragen.
	</li>
	<li>Entwickler-Seite aufrufen<br />
	<a href="http://developers.facebook.com/docs/reference/plugins/like/">http://developers.facebook.com/docs/reference/plugins/like/</a><br />
	Dort in der Box unter "Step 1" auf "Get Code" klicken und die App-ID aus dem angezeigten Code-Teil entnehmen.
	                </li> 
	</ol>
	<?php
}

function admin_twitter_description() {
	echo '<p>Einstellungen für Twitter. Im Feld "Status" das Wort <code>off</code> eingeben, um Twitter zu deaktivieren.</p>';
}

function admin_gplus_description() {
	echo '<p>Einstellungen für Google+. Im Feld "Status" das Wort <code>off</code> eingeben, um Google+ zu deaktivieren.</p>';
}

function wpssp_settings_page() {
	?>
	<div class="wrap">
	<h2>WP socialshareprivacy</h2>
		<form action="options.php" method="post">
		<?php settings_fields('wpssp-settings-group'); ?>
		<?php do_settings_sections('wpssp'); ?>
		
	    <p class="submit">
	    <input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />
	    </p>
		</form>
	</div>
	
	<?php
}

function main() {
	
	// Frontend
	wp_enqueue_script("jquery");
	add_filter('the_content', 'addContent');
	add_action( 'wp_print_scripts', 'enqueue_scripts' );
	add_action( 'wp_print_styles', 'enqueue_styles' );
	
	// Backend
	if ( is_admin() ) {
		add_action('admin_menu', 'create_admin_menu');
	}
}

main();

?>